package	jp.co.sds_corp.tool.mail;

import java.io.FileInputStream;
import java.io.FileOutputStream;
import java.io.InputStream;
import java.util.Properties;

import javax.mail.Multipart;
import javax.mail.Session;
import javax.mail.internet.MimeBodyPart;
import javax.mail.internet.MimeMessage;
import javax.mail.internet.MimeUtility;

public class MailReader
{
	Session session;
	MimeMessage	msg;
	boolean bPrint = false;
	int	nPart = 0;

	public MailReader( String file ) throws Exception {
		this( new FileInputStream( file ));
	}

	public MailReader( InputStream is ) throws Exception {
		Properties props = System.getProperties();
		props.put( "mail.smtp.host", "smtp.sds-corp.co.jp" ); //host );
		session = Session.getDefaultInstance( props, null );
		session.setDebug( false );

		msg = new MimeMessage( session, is );
	}

	public void print() throws Exception {
		System.out.println( "Subject:" + msg.getSubject() );
		String type = msg.getContentType();
		System.out.println( "ContentType:" + type );
		Object obj = msg.getContent();
		if ( type.startsWith( "text" )) {
			if ( bPrint ) {
				System.out.println( obj );
			}
		} else if ( type.startsWith( "multipart" )) {
			Multipart mp = (Multipart )obj;
			for ( int i = 0; i < mp.getCount(); i++ ) {
				MimeBodyPart bp = (MimeBodyPart )mp.getBodyPart( i );
				printBody( bp );
			}
		} else {
			System.out.println( obj );
		}
	}

	public void printBody( MimeBodyPart bp ) throws Exception {
		String type = bp.getContentType();
		System.out.println( "Type:" + type );
		if ( type.startsWith( "text" )) {
			if ( bPrint ) {
				System.out.println( bp.getContent() );
			}
		} else {
			String file = bp.getFileName();
			if ( file == null ) {
				file = "attached." + nPart++;
			}
			file = MimeUtility.decodeText( file );
			System.out.println( "Filename:" + file );
			FileOutputStream os = new FileOutputStream( file );
			InputStream is = bp.getInputStream();
			byte[] buf = new byte[10240];
			for ( ;; ) {
				int nRet = is.read( buf, 0, buf.length );
				if ( nRet < 0 ) {
					break;
				}
				os.write( buf, 0, nRet );
			}
			is.close();
			os.flush();
			os.close();
		}
	}

	public static void main( String[] args ) {
		boolean bPrint = false;
		try {
			String var;
			var = System.getProperty( "mail.print" );
			if ( var != null && var.equals( "true" )) {
				bPrint = true;
			}
			for ( int i = 0; i < args.length; i++ ) {
				MailReader rd = new MailReader( args[i] );
				rd.bPrint = bPrint;
				rd.print();
			}
		} catch ( Exception e ) {
			e.printStackTrace();
		}
	}
}
